==> org-lsst-ccs-subsystem-power-buses-1.5.0-sources.jar: org/lsst/ccs/subsystem/power/data/QuadBoxState.java <==
package org.lsst.ccs.subsystem.power.data;

import java.io.Serializable;
import org.lsst.ccs.subsystem.power.constants.QuadBoxSwitches;
import org.lsst.ccs.subsystem.power.constants.SwitchState;

/**
 *  Contains the state of the quad box subsystem
 *
 *  @author Owen Saxton
 */
public class QuadBoxState implements Serializable {
    
    public final static String KEY = "QuadBoxState";

    private int tickMillis;         // Data status update period (ms)
    private final SwitchState[][] switchState = new SwitchState[QuadBoxSwitches.NUM_DEVICES][]; 
 
    public QuadBoxState()
    {
        switchState[QuadBoxSwitches.DEVC_BFR]
            = new SwitchState[QuadBoxSwitches.NUM_SWITCHES[QuadBoxSwitches.DEVC_BFR] + 1];
        switchState[QuadBoxSwitches.DEVC_PDU_5V]
            = new SwitchState[QuadBoxSwitches.NUM_SWITCHES[QuadBoxSwitches.DEVC_PDU_5V] + 1];
        switchState[QuadBoxSwitches.DEVC_PDU_24VC]
            = new SwitchState[QuadBoxSwitches.NUM_SWITCHES[QuadBoxSwitches.DEVC_PDU_24VC] + 1];
        switchState[QuadBoxSwitches.DEVC_PDU_24VD]
            = new SwitchState[QuadBoxSwitches.NUM_SWITCHES[QuadBoxSwitches.DEVC_PDU_24VD] + 1];
        switchState[QuadBoxSwitches.DEVC_PDU_48V]
            = new SwitchState[QuadBoxSwitches.NUM_SWITCHES[QuadBoxSwitches.DEVC_PDU_48V] + 1];
    }
    
    public void setTickMillis(int tickMillis)
    {
        this.tickMillis = tickMillis;
    }
    
    public int getTickMillis()
    {
        return tickMillis;
    }

    public void setSwitchState(int devNum, int swNum, SwitchState st)
    {
        switchState[devNum][swNum + 1] = st;
    }
    
    public SwitchState getSwitchState(int devNum, int swNum)
    {
        return switchState[devNum][swNum + 1];
    }

    private static final long serialVersionUID = -2984598040851030945L;
}

==> org-lsst-ccs-subsystem-power-buses-1.5.1-sources.jar: org/lsst/ccs/subsystem/power/data/QuadBoxState.java <==
package org.lsst.ccs.subsystem.power.data;

import java.io.Serializable;
import org.lsst.ccs.subsystem.power.constants.QuadBoxSwitches;
import org.lsst.ccs.subsystem.power.constants.SwitchState;

/**
 *  Contains the state of the quad box subsystem
 *
 *  @author Owen Saxton
 */
public class QuadBoxState implements Serializable {
    
    public final static String KEY = "QuadBoxState";

    private int tickMillis;         // Data status update period (ms)
    private final SwitchState[][] switchState = new SwitchState[QuadBoxSwitches.NUM_DEVICES][]; 
 
    public QuadBoxState()
    {
        switchState[QuadBoxSwitches.DEVC_BFR]
            = new SwitchState[QuadBoxSwitches.NUM_SWITCHES[QuadBoxSwitches.DEVC_BFR] + 1];
        switchState[QuadBoxSwitches.DEVC_PDU_5V]
            = new SwitchState[QuadBoxSwitches.NUM_SWITCHES[QuadBoxSwitches.DEVC_PDU_5V] + 1];
        switchState[QuadBoxSwitches.DEVC_PDU_24VC]
            = new SwitchState[QuadBoxSwitches.NUM_SWITCHES[QuadBoxSwitches.DEVC_PDU_24VC] + 1];
        switchState[QuadBoxSwitches.DEVC_PDU_24VD]
            = new SwitchState[QuadBoxSwitches.NUM_SWITCHES[QuadBoxSwitches.DEVC_PDU_24VD] + 1];
        switchState[QuadBoxSwitches.DEVC_PDU_48V]
            = new SwitchState[QuadBoxSwitches.NUM_SWITCHES[QuadBoxSwitches.DEVC_PDU_48V] + 1];
        switchState[QuadBoxSwitches.DEVC_REB_BULK]
            = new SwitchState[QuadBoxSwitches.NUM_SWITCHES[QuadBoxSwitches.DEVC_REB_BULK] + 1];
    }
    
    public void setTickMillis(int tickMillis)
    {
        this.tickMillis = tickMillis;
    }
    
    public int getTickMillis()
    {
        return tickMillis;
    }

    public void setSwitchState(int devNum, int swNum, SwitchState st)
    {
        switchState[devNum][swNum + 1] = st;
    }
    
    public SwitchState getSwitchState(int devNum, int swNum)
    {
        return switchState[devNum][swNum + 1];
    }

    private static final long serialVersionUID = -2984598040851030945L;
}
